package com.rv.im;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.widget.LinearLayout;

import com.ruiwenliu.wrapper.base.BaseBean;
import com.ruiwenliu.wrapper.base.BaseStatusActivity;
import com.ruiwenliu.wrapper.base.presenter.CommonPresenter;
import com.ruiwenliu.wrapper.weight.TitleView;
import com.ruiwenliu.wrapper.weight.refresh.SimpleRefreshLayout;
import com.ruiwenliu.wrapper.weight.refresh.SimpleRefreshView;
import com.rv.im.adapter.CustomerListAdapter;
import com.rv.im.bean.CustomersBean;
import com.rv.im.db.service.CustomerServiceImp;
import com.rv.im.db.service.ICustomerService;
import com.rv.im.db.table.Customer;

import java.util.ArrayList;
import java.util.List;

public class CustomerListActivity extends BaseStatusActivity<CommonPresenter> implements SimpleRefreshLayout.OnSimpleRefreshListener {

    private SimpleRefreshLayout refreshLayout;
    private RecyclerView recyclerView;
    private List<Customer> customers = new ArrayList<>();
    private CustomerListAdapter adapter = null;

    @Override
    protected int setLayout() {
        return R.layout.activity_customer_list;
    }

    @Override
    protected void initView(Bundle savedInstanceState, TitleView titleView, Intent intent) {
        titleView.setTitle("客服列表");
        refreshLayout = findViewById(R.id.refresh);
        recyclerView = findViewById(R.id.recyclerView);
        recyclerView.setLayoutManager(new LinearLayoutManager(this, LinearLayout.VERTICAL, false));
        adapter = new CustomerListAdapter(customers);
        adapter.setOnItemClickListener((adapter, view, position) -> {
            Customer customer = customers.get(position);
            startActivity(ChatActivity.getIntent(getApplicationContext(), customer.getImUserId(), customer.getName()));
        });
        refreshLayout.setHeaderView(new SimpleRefreshView(this));
        refreshLayout.setOnSimpleRefreshListener(this);
        recyclerView.setAdapter(adapter);
    }

    @Override
    protected void loadData(Bundle savedInstanceState, Intent intent) {
        super.loadData(savedInstanceState, intent);
        getCustomerList();
    }

    /******
     * 获取客服列表
     */
    private void getCustomerList() {
        List<Customer> lists = getCustomService().getCustomerLists();
        if (lists == null || lists.size() == 0) {
            mPresenter.getData(0, ImUrlConfig.HTTP_CUSTOMER_LIST_URL, CustomersBean.class, true);
        } else {
            customers.addAll(lists);
            adapter.notifyDataSetChanged();
        }
    }

    private boolean isRefresh = false;

    @Override
    public void onShowResult(int requestType, BaseBean result) {
        if (requestType == 0) {
            CustomersBean bean = (CustomersBean) result;
            if (bean != null && bean.isRel() && bean.getData() != null && bean.getData().size() > 0) {
                if (isRefresh) {
                    refreshLayout.onRefreshComplete();
                    isRefresh = false;
                }
                customers.clear();
                customers.addAll(bean.getData());
                adapter.notifyDataSetChanged();
                getCustomService().addCustomers(customers);
            }
        }
    }

    @Override
    public void onRefresh() {
        isRefresh = true;
        mPresenter.getData(0, ImUrlConfig.HTTP_CUSTOMER_LIST_URL, CustomersBean.class, true);
    }

    private ICustomerService iCustomerService;

    private ICustomerService getCustomService() {
        if (iCustomerService == null) {
            iCustomerService = CustomerServiceImp.getInstance(getApplicationContext());
        }
        return iCustomerService;
    }

}
